@@ -18,24 +18,30 @@ Geo::Coder::US::Census - Provides a Geo-Coding functionality for the US using L<
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
       use Geo::Coder::US::Census;
 
       my $geo_coder = Geo::Coder::US::Census->new();
+      # Get geocoding results (as a hash decoded from JSON)
       my $location = $geo_coder->geocode(location => '4600 Silver Hill Rd., Suitland, MD');
       # Sometimes the server gives a 500 error on this
       $location = $geo_coder->geocode(location => '4600 Silver Hill Rd., Suitland, MD, USA');
 
 =head1 DESCRIPTION
 
-Geo::Coder::US::Census provides an interface to geocoding.geo.census.gov.  Geo::Coder::US no longer seems to work.
+Geo::Coder::US::Census provides geocoding functionality specifically for U.S. addresses by interfacing with the U.S. Census Bureau's geocoding service.
+It allows developers to convert street addresses into geographical coordinates (latitude and longitude) by querying the Census Bureau's API.
+Using L<LWP::UserAgent> (or a user-supplied agent), the module constructs and sends an HTTP GET request to the API.
+
+The module uses L<Geo::StreetAddress::US> to break down a given address into its components (street, city, state, etc.),
+ensuring that the necessary details for geocoding are present.
 
 =head1 METHODS
 
@@ -49,20 +55,32 @@ Geo::Coder::US::Census provides an interface to geocoding.geo.census.gov.  Geo::
 =cut
 
 sub new {
-	my($class, %param) = @_;
+	my $class = $_[0];
 
-	my $ua = $param{ua};
+	shift;
+	my %args = (ref($_[0]) eq 'HASH') ? %{$_[0]} : @_;
+
+	my $ua = $args{ua};
 	if(!defined($ua)) {
 		$ua = LWP::UserAgent->new(agent => __PACKAGE__ . "/$VERSION");
 		$ua->default_header(accept_encoding => 'gzip,deflate');
+		$ua->env_proxy(1);
 	}
-	my $host = $param{host} || 'geocoding.geo.census.gov/geocoder/locations/address';
+	my $host = $args{host} || 'geocoding.geo.census.gov/geocoder/locations/address';
 
-	return bless { ua => $ua, host => $host }, $class;
+	return bless { ua => $ua, host => $host, %args }, $class;
 }
 
 =head2 geocode
 
+Geocode an address.
+It accepts addresses provided in various forms -
+whether as a single argument, a key/value pair, or within a hash reference -
+making it easy to integrate into different codebases.
+It decodes the JSON response from the API using L<JSON::MaybeXS>,
+providing the result as a hash.
+This allows easy extraction of latitude, longitude, and other details returned by the service.
+
     $location = $geo_coder->geocode(location => $location);
     # @location = $geo_coder->geocode(location => $location);
 
@@ -110,6 +128,8 @@ sub geocode {
 	my $hr = Geo::StreetAddress::US->parse_address($location);
 
 	if((!defined($hr->{'city'})) || (!defined($hr->{'state'}))) {
+		# use Data::Dumper;
+		# print Data::Dumper->new([$hr])->Dump(), "\n";
 		Carp::carp(__PACKAGE__ . ": city and state are mandatory ($location)");
 		return;
 	}
@@ -177,6 +197,7 @@ sub ua {
 # Similar to geocode except it expects a latitude/longitude parameter.
 
 Not supported.
+Croaks if this method is called.
 
 =cut
 
@@ -194,12 +215,17 @@ sub reverse_geocode {
 		# or Carp::croak("Usage: reverse_geocode(latlng => \$latlng)");
 
 	# return $self->geocode(location => $latlng, reverse => 1);
-	Carp::croak('Reverse geocode is not supported');
+	Carp::croak(__PACKAGE__, ': Reverse geocode is not supported');
 }
 
 =head2 run
 
-You can also run this module from the command line:
+In addition to being used as a library within other Perl scripts,
+L<Geo::Coder::US::Census> can be run directly from the command line.
+When invoked this way,
+it accepts an address as input,
+performs geocoding,
+and prints the resulting data structure via L<Data::Dumper>.
 
     perl Census.pm 1600 Pennsylvania Avenue NW, Washington DC
 
@@ -234,8 +260,6 @@ Lots of thanks to the folks at geocoding.geo.census.gov.
 
 =head1 BUGS
 
-Should be called Geo::Coder::NA for North America.
-
 =head1 SEE ALSO
 
 L<Geo::Coder::GooglePlaces>, L<HTML::GoogleMaps::V3>
@@ -244,7 +268,7 @@ https://www.census.gov/data/developers/data-sets/Geocoding-services.html
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017-2023 Nigel Horne.
+Copyright 2017-2025 Nigel Horne.
 
 This program is released under the following licence: GPL2
 
